@@ -16,7 +16,7 @@ import (
 	"text/template"
 
 	"github.com/Masterminds/sprig/v3"
-	"github.com/google/go-github/v52/github"
+	"github.com/google/go-github/v53/github"
 	"github.com/google/renameio/v2/maybe"
 	"gopkg.in/yaml.v3"
 
@@ -51,7 +51,12 @@ func (c *gitHubClient) gitHubListReleases(ownerRepo string) []*github.Repository
 		PerPage: 100,
 	}
 	for {
-		repositoryReleases, resp, err := c.client.Repositories.ListReleases(c.ctx, owner, repo, opts)
+		repositoryReleases, resp, err := c.client.Repositories.ListReleases(
+			c.ctx,
+			owner,
+			repo,
+			opts,
+		)
 		if err != nil {
 			panic(err)
 		}
