@@ -31,7 +31,13 @@ func (c *Config) newApplyCmd() *cobra.Command {
 	flags.VarP(c.apply.filter.Exclude, "exclude", "x", "Exclude entry types")
 	flags.VarP(c.apply.filter.Include, "include", "i", "Include entry types")
 	flags.BoolVar(&c.apply.init, "init", c.apply.init, "Recreate config file from template")
-	flags.BoolVarP(&c.apply.recursive, "recursive", "r", c.apply.recursive, "Recurse into subdirectories")
+	flags.BoolVarP(
+		&c.apply.recursive,
+		"recursive",
+		"r",
+		c.apply.recursive,
+		"Recurse into subdirectories",
+	)
 
 	registerExcludeIncludeFlagCompletionFuncs(applyCmd)
 
